==> dcl-c_5.3.3.orig.tar.gz: dcl-c-5.3.3/src/grph2/ucpack/ucxacl.c <==
/*  -- translated by f2c (version 20050501).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__2 = 2;

/* ----------------------------------------------------------------------- */
/*     UCXACL : PLOT CALENDAR AXIS */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int ucxacl_(char *cside, integer *jd0, integer *nd, ftnlen 
	cside_len)
{
    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
	    ftnlen, ftnlen), ucxamn_(char *, integer *, integer *, ftnlen), 
	    ucxady_(char *, integer *, integer *, ftnlen);
    extern logical luxchk_(char *, ftnlen);
    extern /* Subroutine */ int ucxayr_(char *, integer *, integer *, ftnlen),
	     uxpaxs_(char *, integer *, ftnlen);

    if (! luxchk_(cside, (ftnlen)1)) {
	msgdmp_("E", "UCXACL", "SIDE PARAMETER IS INVALID.", (ftnlen)1, (
		ftnlen)6, (ftnlen)26);
    }
    if (*jd0 < 0) {
	msgdmp_("E", "UCXACL", "FIRST DATE IS LESS THAN 0.", (ftnlen)1, (
		ftnlen)6, (ftnlen)26);
    }
    if (*nd <= 0) {
	msgdmp_("E", "UCXACL", "DATE LENGTH IS LESS THAN 0.", (ftnlen)1, (
		ftnlen)6, (ftnlen)27);
    }
    uxpaxs_(cside, &c__2, (ftnlen)1);
    ucxady_(cside, jd0, nd, (ftnlen)1);
    ucxamn_(cside, jd0, nd, (ftnlen)1);
    ucxayr_(cside, jd0, nd, (ftnlen)1);
    return 0;
} /* ucxacl_ */

==> dcl-c_5.3-20050523-1.tar.gz: dcl-c-5.3-20050523/src/grph2/ucpack/ucxacl.c <==
/* src/grph2/ucpack/ucxacl.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__2 = 2;

/* ----------------------------------------------------------------------- */
/*     UCXACL : PLOT CALENDAR AXIS */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int ucxacl_(char *cside, integer *jd0, integer *nd, ftnlen 
	cside_len)
{
    extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
	    ftnlen, ftnlen), ucxamn_(char *, integer *, integer *, ftnlen), 
	    ucxady_(char *, integer *, integer *, ftnlen);
    extern logical luxchk_(char *, ftnlen);
    extern /* Subroutine */ int ucxayr_(char *, integer *, integer *, ftnlen),
	     uxpaxs_(char *, integer *, ftnlen);

    if (! luxchk_(cside, (ftnlen)1)) {
	msgdmp_("E", "UCXACL", "SIDE PARAMETER IS INVALID.", (ftnlen)1, (
		ftnlen)6, (ftnlen)26);
    }
    if (*jd0 < 0) {
	msgdmp_("E", "UCXACL", "FIRST DATE IS LESS THAN 0.", (ftnlen)1, (
		ftnlen)6, (ftnlen)26);
    }
    if (*nd <= 0) {
	msgdmp_("E", "UCXACL", "DATE LENGTH IS LESS THAN 0.", (ftnlen)1, (
		ftnlen)6, (ftnlen)27);
    }
    uxpaxs_(cside, &c__2, (ftnlen)1);
    ucxady_(cside, jd0, nd, (ftnlen)1);
    ucxamn_(cside, jd0, nd, (ftnlen)1);
    ucxayr_(cside, jd0, nd, (ftnlen)1);
    return 0;
} /* ucxacl_ */
